==> jc-1.4.0.tar.gz: java/net/URLClassLoader__24FileResource.h <==
// final class java.net.URLClassLoader$FileResource

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 9c4c7aee9c349136 java_net_URLClassLoader__24FileResource
// @dep_class 9d385c5a860bc53d java_net_URLClassLoader__24Resource

// header file dependencies
// @dep_header java_net_URLClassLoader__24Resource

#include "java/net/URLClassLoader__24Resource.h"

#ifndef _JC_java_net_URLClassLoader__24FileResource_H_
#define _JC_java_net_URLClassLoader__24FileResource_H_

// Forward structure declarations
struct _jc_java_io_File$object;
struct _jc_java_io_InputStream$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_net_URL$object;
struct _jc_java_net_URLClassLoader__24FileURLLoader$object;

// Typedefs
typedef struct _jc_java_net_URLClassLoader__24FileResource$sub_refs	_jc_java_net_URLClassLoader__24FileResource$sub_refs;
typedef struct _jc_java_net_URLClassLoader__24FileResource$sub_nonrefs	_jc_java_net_URLClassLoader__24FileResource$sub_nonrefs;
typedef struct _jc_java_net_URLClassLoader__24FileResource$refs	_jc_java_net_URLClassLoader__24FileResource$refs;
typedef struct _jc_java_net_URLClassLoader__24FileResource$nonrefs	_jc_java_net_URLClassLoader__24FileResource$nonrefs;
typedef struct _jc_java_net_URLClassLoader__24FileResource$object	_jc_java_net_URLClassLoader__24FileResource$object;

typedef const struct _jc_java_net_URLClassLoader__24FileResource$vmethods	_jc_java_net_URLClassLoader__24FileResource$vmethods;
typedef const struct _jc_java_net_URLClassLoader__24FileResource$vtable	_jc_java_net_URLClassLoader__24FileResource$vtable;
typedef const struct _jc_java_net_URLClassLoader__24FileResource$vtype	_jc_java_net_URLClassLoader__24FileResource$vtype;

// Constructors
extern void _jc_java_net_URLClassLoader__24FileResource$method$_init$58cc5edb3869205b(_jc_env *, struct _jc_java_net_URLClassLoader__24FileResource$object *, struct _jc_java_net_URLClassLoader__24FileURLLoader$object *, struct _jc_java_lang_String$object *, struct _jc_java_io_File$object *);

// Virtual methods
extern struct _jc_java_io_InputStream$object *_jc_java_net_URLClassLoader__24FileResource$method$getInputStream$13cf75a12cabb343(_jc_env *, struct _jc_java_net_URLClassLoader__24FileResource$object *);
extern jint _jc_java_net_URLClassLoader__24FileResource$method$getLength$b9eaa8ec0a00f23d(_jc_env *, struct _jc_java_net_URLClassLoader__24FileResource$object *);
extern struct _jc_java_net_URL$object *_jc_java_net_URLClassLoader__24FileResource$method$getURL$f8efe3e882b98c02(_jc_env *, struct _jc_java_net_URLClassLoader__24FileResource$object *);

// Virtual method descriptors
extern _jc_method _jc_java_net_URLClassLoader__24FileResource$method_info$getInputStream$13cf75a12cabb343;
extern _jc_method _jc_java_net_URLClassLoader__24FileResource$method_info$getLength$b9eaa8ec0a00f23d;
extern _jc_method _jc_java_net_URLClassLoader__24FileResource$method_info$getURL$f8efe3e882b98c02;

// Virtual methods structure
struct _jc_java_net_URLClassLoader__24FileResource$vmethods {
	struct _jc_java_io_InputStream$object	*(*getInputStream$13cf75a12cabb343)(_jc_env *, struct _jc_java_net_URLClassLoader__24FileResource$object *);
	jint	(*getLength$b9eaa8ec0a00f23d)(_jc_env *, struct _jc_java_net_URLClassLoader__24FileResource$object *);
	struct _jc_java_net_URL$object	*(*getURL$f8efe3e882b98c02)(_jc_env *, struct _jc_java_net_URLClassLoader__24FileResource$object *);
};

// Vtable
struct _jc_java_net_URLClassLoader__24FileResource$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_net_URLClassLoader__24Resource$vmethods	java_net_URLClassLoader__24Resource;
	_jc_java_net_URLClassLoader__24FileResource$vmethods	java_net_URLClassLoader__24FileResource;
};

// Vtype
struct _jc_java_net_URLClassLoader__24FileResource$vtype {
	_jc_type			type;
	_jc_java_net_URLClassLoader__24FileResource$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_net_URLClassLoader__24FileResource$sub_refs {
	struct _jc_java_io_File$object	*file;
};

// Reference instance fields (object)
struct _jc_java_net_URLClassLoader__24FileResource$refs {
    _jc_java_net_URLClassLoader__24FileResource$sub_refs	java_net_URLClassLoader__24FileResource;
    _jc_java_net_URLClassLoader__24Resource$sub_refs	java_net_URLClassLoader__24Resource;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_net_URLClassLoader__24FileResource$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_net_URLClassLoader__24FileResource$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_net_URLClassLoader__24Resource$sub_nonrefs	java_net_URLClassLoader__24Resource;
    _jc_java_net_URLClassLoader__24FileResource$sub_nonrefs	java_net_URLClassLoader__24FileResource;
};

// Object instance structure
struct _jc_java_net_URLClassLoader__24FileResource$object {
	_jc_java_net_URLClassLoader__24FileResource$refs	refs[0];
	_jc_word		lockword;
	_jc_java_net_URLClassLoader__24FileResource$vtype	*vtype;
	_jc_java_net_URLClassLoader__24FileResource$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_net_URLClassLoader__24FileResource$vtype _jc_java_net_URLClassLoader__24FileResource$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_net_URLClassLoader__24FileResource, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_net_URLClassLoader__24FileResource$class_object;

#endif	/* _JC_java_net_URLClassLoader__24FileResource_H_ */

==> jc-1.4.5.tar.gz: java/net/URLClassLoader__24FileResource.h <==
// final class java.net.URLClassLoader$FileResource

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 23841aefbe4e4b75 java_net_URLClassLoader__24FileResource
// @dep_class 9d385c5a860bc53d java_net_URLClassLoader__24Resource

// header file dependencies
// @dep_header java_net_URLClassLoader__24Resource

#include "java/net/URLClassLoader__24Resource.h"

#ifndef _JC_java_net_URLClassLoader__24FileResource_H_
#define _JC_java_net_URLClassLoader__24FileResource_H_

// Forward structure declarations
struct _jc_java_io_File$object;
struct _jc_java_io_InputStream$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_net_URL$object;
struct _jc_java_net_URLClassLoader__24FileURLLoader$object;

// Typedefs
typedef struct _jc_java_net_URLClassLoader__24FileResource$sub_refs	_jc_java_net_URLClassLoader__24FileResource$sub_refs;
typedef struct _jc_java_net_URLClassLoader__24FileResource$sub_nonrefs	_jc_java_net_URLClassLoader__24FileResource$sub_nonrefs;
typedef struct _jc_java_net_URLClassLoader__24FileResource$refs	_jc_java_net_URLClassLoader__24FileResource$refs;
typedef struct _jc_java_net_URLClassLoader__24FileResource$nonrefs	_jc_java_net_URLClassLoader__24FileResource$nonrefs;
typedef struct _jc_java_net_URLClassLoader__24FileResource$object	_jc_java_net_URLClassLoader__24FileResource$object;

typedef const struct _jc_java_net_URLClassLoader__24FileResource$vmethods	_jc_java_net_URLClassLoader__24FileResource$vmethods;
typedef const struct _jc_java_net_URLClassLoader__24FileResource$vtable	_jc_java_net_URLClassLoader__24FileResource$vtable;
typedef const struct _jc_java_net_URLClassLoader__24FileResource$vtype	_jc_java_net_URLClassLoader__24FileResource$vtype;

// Constructors
extern void _jc_java_net_URLClassLoader__24FileResource$method$_init$58cc5edb3869205b(_jc_env *, struct _jc_java_net_URLClassLoader__24FileResource$object *, struct _jc_java_net_URLClassLoader__24FileURLLoader$object *, struct _jc_java_lang_String$object *, struct _jc_java_io_File$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_io_InputStream$object *_jc_java_net_URLClassLoader__24FileResource$method$getInputStream$13cf75a12cabb343(_jc_env *, struct _jc_java_net_URLClassLoader__24FileResource$object *) _JC_JCNI_ATTR;
extern jint _jc_java_net_URLClassLoader__24FileResource$method$getLength$b9eaa8ec0a00f23d(_jc_env *, struct _jc_java_net_URLClassLoader__24FileResource$object *) _JC_JCNI_ATTR;
extern struct _jc_java_net_URL$object *_jc_java_net_URLClassLoader__24FileResource$method$getURL$f8efe3e882b98c02(_jc_env *, struct _jc_java_net_URLClassLoader__24FileResource$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_java_net_URLClassLoader__24FileResource$method_info$getInputStream$13cf75a12cabb343;
extern _jc_method _jc_java_net_URLClassLoader__24FileResource$method_info$getLength$b9eaa8ec0a00f23d;
extern _jc_method _jc_java_net_URLClassLoader__24FileResource$method_info$getURL$f8efe3e882b98c02;

// Virtual methods structure
struct _jc_java_net_URLClassLoader__24FileResource$vmethods {
	struct _jc_java_io_InputStream$object	*(*getInputStream$13cf75a12cabb343)(_jc_env *, struct _jc_java_net_URLClassLoader__24FileResource$object *) _JC_JCNI_ATTR;
	jint	(*getLength$b9eaa8ec0a00f23d)(_jc_env *, struct _jc_java_net_URLClassLoader__24FileResource$object *) _JC_JCNI_ATTR;
	struct _jc_java_net_URL$object	*(*getURL$f8efe3e882b98c02)(_jc_env *, struct _jc_java_net_URLClassLoader__24FileResource$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_java_net_URLClassLoader__24FileResource$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_net_URLClassLoader__24Resource$vmethods	java_net_URLClassLoader__24Resource;
	_jc_java_net_URLClassLoader__24FileResource$vmethods	java_net_URLClassLoader__24FileResource;
};

// Vtype
struct _jc_java_net_URLClassLoader__24FileResource$vtype {
	_jc_type			type;
	_jc_java_net_URLClassLoader__24FileResource$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_net_URLClassLoader__24FileResource$sub_refs {
	struct _jc_java_io_File$object	*file;
};

// Reference instance fields (object)
struct _jc_java_net_URLClassLoader__24FileResource$refs {
    _jc_java_net_URLClassLoader__24FileResource$sub_refs	java_net_URLClassLoader__24FileResource;
    _jc_java_net_URLClassLoader__24Resource$sub_refs	java_net_URLClassLoader__24Resource;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_net_URLClassLoader__24FileResource$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_net_URLClassLoader__24FileResource$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_net_URLClassLoader__24Resource$sub_nonrefs	java_net_URLClassLoader__24Resource;
    _jc_java_net_URLClassLoader__24FileResource$sub_nonrefs	java_net_URLClassLoader__24FileResource;
};

// Object instance structure
struct _jc_java_net_URLClassLoader__24FileResource$object {
	_jc_java_net_URLClassLoader__24FileResource$refs	refs[0];
	_jc_word		lockword;
	_jc_java_net_URLClassLoader__24FileResource$vtype	*vtype;
	_jc_java_net_URLClassLoader__24FileResource$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_net_URLClassLoader__24FileResource$vtype _jc_java_net_URLClassLoader__24FileResource$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_net_URLClassLoader__24FileResource, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_net_URLClassLoader__24FileResource$class_object;

#endif	/* _JC_java_net_URLClassLoader__24FileResource_H_ */
